lidarwind.lidar\_code.GetLidarData
==================================

.. currentmodule:: lidarwind.lidar_code

.. autoclass:: GetLidarData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GetLidarData.__init__
      ~GetLidarData.open_lidar_file
   
   

   
   
   